package org.jivesoftware.smack;

import java.net.SocketException;

import org.jivesoftware.smack.packet.Packet;

/**
 * This class adds functionality to {@link XMPPConnection} that enables you to
 * disable all outgoing packets. This is useful in checking for errors. Don't
 * use this class to setup XMPPConnections that are supposed to be stable!
 */
public class BlockableXMPPConnection extends XMPPConnection
{
	private boolean enabled = true;
	
	/**
	 * Wrapper for superclass constructor.
	 * 
	 * @param conf
	 *            Connectionconfiguration to use for setting up this connection.
	 */
	public BlockableXMPPConnection(ConnectionConfiguration conf)
	{
		super(conf);
	}

	/**
	 * Stops all outgoing traffic. This should result in the server closing it's
	 * ClientSession associated with this connection after the idle value set in
	 * the 'xmpp.client.idle' property has passed.
	 * @throws SocketException 
	 */
	public void enableOutgoingTraffic(boolean enable) throws SocketException
	{
		enabled = enable;
		socket.setKeepAlive(!enable);
	}
	
	/**
	 * Returns the current allowance of outgoing traffic.
	 * @return ''true'' if outgoing traffic is enabled, ''false'' otherwise.
	 */
	public boolean isOutgoingTrafficEnabled()
	{
		return enabled;
	}
	
	@Override
	public void sendPacket(Packet packet)
	{
		if (enabled)
		{
			super.sendPacket(packet);
		}
	}
}
